==> lxqt-panel_0.14.0.orig.tar.xz: lxqt-panel-0.14.0/plugin-spacer/translations/spacer_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Ayraç Ayarları</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Boşluk genişliği:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>Boşluk türü:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>çizgili</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>noktalı</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>görünmez</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-spacer/translations/spacer_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Ayraç Ayarları</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Boşluk genişliği:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>Boşluk türü:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation>sabit</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation>genişletilebilir</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>çizgili</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>noktalı</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>görünmez</translation>
    </message>
</context>
</TS>
